@@ -20,7 +20,7 @@ from firebirdsql.utils import *
 from firebirdsql.wireprotocol import WireProtocol, INFO_SQL_SELECT_DESCRIBE_VARS
 from firebirdsql.socketstream import SocketStream
 from firebirdsql.xsqlvar import XSQLVAR, calc_blr, parse_select_items, parse_xsqlda
-__version__ = '0.9.3'
+__version__ = '0.9.4'
 apilevel = '2.0'
 threadsafety = 1
 paramstyle = 'qmark'
@@ -286,7 +286,7 @@ class Cursor(object):
                     raise IntegrityError(e._message, e.gds_codes, e.sql_code)
                 if e.sql_code == -303:
                     warnings.warn(e._message)
-                    return
+                    return self
                 else:
                     raise OperationalError(e._message, e.gds_codes, e.sql_code)
 
@@ -298,10 +298,13 @@ class Cursor(object):
             self._callproc_result = None
         self.transaction.is_dirty = True
 
+        return self
+
     def callproc(self, procname, params=[]):
         DEBUG_OUTPUT("Cursor::callproc()")
         query = 'EXECUTE PROCEDURE ' + procname + ' ' + ','.join('?'*len(params))
-        return self.execute(query, params)
+        self.execute(query, params)
+        return self._callproc_result
 
     def executemany(self, query, seq_of_params):
         for params in seq_of_params:
@@ -424,18 +427,8 @@ class Cursor(object):
             assert buf[17:20] == bs([0x0d,0x04,0x00])
                                               # isc_info_req_select_count
             count = bytes_to_int(buf[20:24])
-        elif self.stmt.stmt_type == isc_info_sql_stmt_insert:
-            assert buf[24:27] == bs([0x0e,0x04,0x00])
-                                              # isc_info_req_insert_count
-            count = bytes_to_int(buf[27:31])
-        elif self.stmt.stmt_type == isc_info_sql_stmt_update:
-            assert buf[3:6] == bs([0x0f,0x04,0x00])
-                                              # isc_info_req_update_count
-            count = bytes_to_int(buf[6:10])
-        elif self.stmt.stmt_type == isc_info_sql_stmt_delete:
-            assert buf[10:13] == bs([0x10,0x04,0x00])
-                                              # isc_info_req_delete_count
-            count = bytes_to_int(buf[13:17])
+        else:
+            count = bytes_to_int(buf[27:31]) + bytes_to_int(buf[6:10]) + bytes_to_int(buf[13:17])
         DEBUG_OUTPUT("Cursor::rowcount()", self.stmt.stmt_type, count)
         return count
 
