@@ -441,7 +441,6 @@ class WireProtocol(object):
         self.accept_architecture = bytes_to_bint(b[4:8])
         self.accept_type =  bytes_to_bint(b[8:])
 
-        self.auth_key = None
         if op_code == self.op_cond_accept or op_code == self.op_accept_data:
             read_length = 0
 
@@ -473,40 +472,38 @@ class WireProtocol(object):
 
             if self.plugin_name == b'Srp':
                 ln = bytes_to_int(data[:2])
-                self.server_salt = data[2:ln+2]
-                self.server_public_key = hex_to_bytes(data[4+ln:])
-                self.server_public_key = srp.bytes2long(self.server_public_key)
+                server_salt = data[2:ln+2]
+                server_public_key = srp.bytes2long(
+                                        hex_to_bytes(data[4+ln:]))
 
-                self.client_proof, self.auth_key = srp.client_proof(
+                client_proof, auth_key = srp.client_proof(
                                         self.str_to_bytes(self.user.upper()),
                                         self.str_to_bytes(self.password),
-                                        self.server_salt,
+                                        server_salt,
                                         self.client_public_key,
-                                        self.server_public_key,
+                                        server_public_key,
                                         self.client_private_key)
                 # send op_cont_auth
                 p = xdrlib.Packer()
                 p.pack_int(self.op_cont_auth)
-                p.pack_string(bytes_to_hex(self.client_proof))
+                p.pack_string(bytes_to_hex(client_proof))
                 p.pack_bytes(self.plugin_name)
                 p.pack_bytes(self.plugin_list)
                 p.pack_bytes(b'')
                 self.sock.send(p.get_buffer())
                 (h, oid, buf) = self._op_response()
 
+                # op_crypt: plugin[Arc4] key[Symmetric]
+                p = xdrlib.Packer()
+                p.pack_int(self.op_crypt)
+                p.pack_string(b'Arc4')
+                p.pack_string(b'Symmetric')
+                self.sock.send(p.get_buffer())
+                self.sock.set_translator(Arc4(auth_key), Arc4(auth_key))
+                (h, oid, buf) = self._op_response()
         else:
             assert op_code == self.op_accept
 
-        if self.auth_key:
-            # op_crypt: plugin[Arc4] key[Symmetric]
-            p = xdrlib.Packer()
-            p.pack_int(self.op_crypt)
-            p.pack_string(b'Arc4')
-            p.pack_string(b'Symmetric')
-            self.sock.send(p.get_buffer())
-            self.sock.set_translator(Arc4(self.auth_key), Arc4(self.auth_key))
-            (h, oid, buf) = self._op_response()
-
     @wire_operation
     def _op_attach(self):
         dpb = bs([1])
